import { PerspectiveCamera, Vector3, Object3D, Euler, CubeCamera, Frustum, Box3 } from 'three';
import { AppManager } from '../../ByondViewer';
import { EasingType } from '../../Utils/Utils';
import { Subscription } from 'rxjs';
import { GyroscopeManager } from '../../Utils/GyroscopeManager';
import { RenderManager } from '../../Core/RenderManager';
export interface ICameraControls {
    camera: PerspectiveCamera;
    enabled: boolean;
    appManager: AppManager;
    init(cam: PerspectiveCamera): any;
    enable(): any;
    disable(): any;
    destroy(): any;
    _render(): any;
    setCameraHeight(floor: number, userHeight: number): any;
}
export declare abstract class CameraControlsImpl implements ICameraControls {
    protected cubeCamera: CubeCamera;
    camera: PerspectiveCamera;
    enabled: boolean;
    appManager: AppManager;
    resizeFunc: any;
    onDelayResizeFunc: any;
    protected cameraRotation: Euler;
    isVR: boolean;
    vrDisplay: VRDisplay;
    gyroManager: GyroscopeManager;
    renderManager: RenderManager;
    gyroPresent: boolean;
    gyroEnabled: boolean;
    isGyroPresentFunc: any;
    subscribtions: Array<Subscription>;
    frustum: Frustum;
    onCameraMoveFunc: (event?: any) => void;
    onCameraZoomFunc: (event?: any) => void;
    IsCameraFreezed: boolean;
    private dummyCalcObj;
    constructor(appManager: AppManager);
    onCameraMove(): void;
    onCameraZoom(): void;
    freezeCamera(freeze: boolean): void;
    calcFrustum(): void;
    abstract setCameraOptions(options: any): any;
    abstract setCameraAttr(cameraAttr: any): any;
    init(cam?: PerspectiveCamera, display?: VRDisplay): Promise<void>;
    getAngleXFromCamera(object: Object3D, isLookAt?: boolean): any;
    calcDistanceFromCamera(obj: Object3D): number;
    resetGyro(cameraRotationAsCenter?: boolean): void;
    isAndroid(): boolean;
    enableGyro(): void;
    disableGyro(): void;
    isObjectVisible(box: Box3): boolean;
    getCubeCamera(): CubeCamera;
    enable(): void;
    disable(): void;
    addListeners(): void;
    removeListeners(): void;
    onDelayResize(): Promise<void>;
    prevHeight: number;
    onResize(): Promise<void>;
    abstract _render(time?: any): any;
    destroy(): void;
    setCameraHeight(y: number, time?: number): Promise<void>;
    animateCamera(position: Vector3, lookAt?: Vector3, setTarget?: boolean, time?: number, onUpdatePosition?: Array<Function>, onUpdateRotaion?: Array<Function>, easing?: EasingType): Promise<void>;
    changeCamPosition(targetPosition: Vector3, time?: number, onUpdate?: Array<Function>, easing?: EasingType): Promise<void>;
    changeCamRotation(lookAtTarget: Vector3, assumePosition: Vector3, time?: number, onUpdate?: Array<Function>): Promise<void>;
    handleGyro(): void;
    GetLookAtQuaternion(obj: Object3D, lookAtPosition: Vector3, assumePosition: Vector3): import("three").Quaternion;
    FocusCameraOnObject(obj: THREE.Object3D | Array<THREE.Object3D>, time?: number, screenCoverage?: number, onUpdate?: Array<Function>, easing?: EasingType): Promise<void>;
}
