import { CameraControlsImpl, ICameraControls } from './CameraControlsImpl';
import { AppManager } from '../../ByondViewer';
import { Vector3, PerspectiveCamera } from 'three';
import { GyroOptions } from '../../Utils/GyroscopeManager';
import { OrbitControls } from './Controls/OrbitControls';
export declare abstract class OrbitBasedCameraControls extends CameraControlsImpl implements ICameraControls {
    orbitControls: OrbitControls;
    orbitOptions: OrbitControlsOptions;
    camera: PerspectiveCamera;
    rotateSpeed: number;
    target: {
        x: number;
        y: number;
        z: number;
    };
    autoRotateThreshold: number;
    autoRotateTimer: number;
    didSwipeDisableGyro: boolean;
    constructor(appManager: AppManager, options?: OrbitControlsOptions);
    init(cam?: PerspectiveCamera): Promise<void>;
    addListeners(): void;
    removeListeners(): void;
    handleAutoRotate(timeToWait?: number): void;
    stopAutoRotateTimer(): void;
    _updateOrbitControls(): void;
    enable(): void;
    disableGyro(): void;
    enableGyro(): void;
    disable(): void;
    abstract _render(): any;
    destroy(): void;
    setCameraHeight(floor: number, userHeight: number): Promise<void>;
    animateCamera(position: Vector3, lookAt?: Vector3, setTarget?: boolean, time?: number, onUpdatePosition?: Array<Function>, onUpdateRotaion?: Array<Function>): Promise<void>;
    abstract setCameraOptions(options: OrbitControlsOptions): any;
    abstract setCameraAttr(cameraAttr: any): any;
}
export declare class OrbitControlsOptions {
    target: any;
    position: any;
    max_distance: number;
    min_distance: number;
    max_polar_angle: number;
    min_polar_angle: number;
    max_azimuth_angle: number;
    min_azimuth_angle: number;
    max_zoom: number;
    min_zoom: number;
    max_y: number;
    min_y: number;
    auto_rotate: boolean;
    auto_rotate_speed: number;
    enable_pan: string;
    gyro: GyroOptions;
    angular_rotation: any;
    auto_rotate_threshold: number;
    fps: number;
}
