import { ByondBaseElement } from '../../Core/ByondBaseElement';
import { Object3D, Vector3 } from 'three';
import { AppManager } from '../../ByondViewer';
export declare class InteractableActions {
    private _actionableInstructions;
    Add(descriptorType: string, executable: Executable): void;
    private AssertIfNull;
    Contains(descriptor: ByondCommonActionDescriptor): boolean;
    Execute(descriptor: ByondCommonActionDescriptor): void;
    Remove(descriptorType: string): void;
    Clear(): void;
}
export interface Interactable {
    interactableActions: InteractableActions;
    obj: ByondBaseElement;
    getParentElementHandlers(): Array<ByondBaseElement>;
}
export declare class InteractableImpl {
    interactableActions: InteractableActions;
    obj: ByondBaseElement;
    constructor(obj?: ByondBaseElement);
    getParentElementHandlers(): Array<ByondBaseElement>;
    dispose(): void;
}
export declare abstract class ByondCommonActionDescriptor {
    static typeName: string;
    protected _interactable: Interactable;
    get interactable(): Interactable;
    get typeName(): string;
    protected _handlers: Array<ByondBaseElement>;
    constructor(inter?: Interactable);
    get handlers(): Array<ByondBaseElement>;
}
export interface Executable {
    appManager: AppManager;
    execute(descriptor: ByondCommonActionDescriptor): any;
}
export declare class GeneralExecutable implements Executable {
    appManager: AppManager;
    action: Function;
    constructor(appManager: AppManager, action: Function);
    execute(descriptor: ByondCommonActionDescriptor): void;
}
export declare class HitDetails {
    HitLocation: Vector3;
    Mesh: Object3D;
}
export declare abstract class ByondElementInteractionActionDescriptor extends ByondCommonActionDescriptor {
    static typeName: string;
    Hit: HitDetails;
    constructor(inter: Interactable, hit: HitDetails);
    get typeName(): string;
}
export declare class TouchActionDescriptor extends ByondElementInteractionActionDescriptor {
    static typeName: string;
    constructor(interactable: Interactable, hit?: HitDetails);
    get typeName(): string;
}
export declare class LongTouchActionDescriptor extends ByondElementInteractionActionDescriptor {
    static typeName: string;
    constructor(interactable: Interactable, hit?: HitDetails);
    get typeName(): string;
}
export declare class LongTouchEndedActionDescriptor extends ByondElementInteractionActionDescriptor {
    static typeName: string;
    constructor(interactable: Interactable, hit?: HitDetails);
    get typeName(): string;
}
export declare class DoubleClickActionDescriptor extends ByondElementInteractionActionDescriptor {
    static typeName: string;
    constructor(interactable: Interactable, hit?: HitDetails);
    get typeName(): string;
}
export declare class FocusActionDescriptor extends ByondElementInteractionActionDescriptor {
    static typeName: string;
    constructor(interactable: Interactable, hit?: HitDetails);
    get typeName(): string;
}
export declare class UnfocusActionDescriptor extends ByondElementInteractionActionDescriptor {
    static typeName: string;
    constructor(interactable: Interactable, mesh: Object3D);
    get typeName(): string;
}
