import { Vector3, Euler, MeshBasicMaterial, Geometry, BufferGeometry, MeshStandardMaterial, BoxHelper } from 'three';
import { Metadata } from './Metadata';
import { ByondBaseElement } from './ByondBaseElement';
import { IEditorEventMessage } from './EventManager/EventMessageImpl';
import { ChromakeyMaterial } from './Materials/ChromakeyMaterial';
import { Flow, OnEvent, Step } from './ElementsEventsCustumAttribute';
export declare class AnimationOptions {
    Position?: Vector3;
    Rotation?: Euler;
    Scale?: Vector3;
    Color?: string;
    time?: number;
}
export declare class ByondInteractiveElement extends ByondBaseElement {
    boundingBox: BoxHelper;
    protected material: MeshStandardMaterial | MeshBasicMaterial | ChromakeyMaterial | MeshBasicMaterial[];
    protected geometry: Geometry | BufferGeometry;
    protected metadata: Metadata.Element3DMetadata;
    protected _isActive: boolean;
    attachedTeleport: any;
    constructor(metadata: Metadata.Element3DMetadata, parent: ByondBaseElement, element_id?: string);
    init(): Promise<void>;
    HandleEditorEventStarted(event: IEditorEventMessage): void;
    HandleEditorEventEnded(event: IEditorEventMessage): void;
    setLookAtItem(itemOptions: {
        item: string;
        x: boolean;
        y: boolean;
        z: boolean;
    }): void;
    renderWireframe(onOff: boolean): void;
    traverseMaterials(object: any, callback: any): void;
    showBoundingBox(): void;
    updateTransformMetadata(): void;
    Reset(time?: number): Promise<void>;
    SenarioAnimate(animationSenario: Array<Array<AnimationOptions>>): Promise<void>;
    Animate(animationOptions: AnimationOptions): Promise<any[]>;
    setEnabled(enable: boolean): void;
    setPosition(vector: Vector3, time?: number): Promise<any>;
    setRotation(vector: Euler, time?: number): Promise<any>;
    setScale(vector: Vector3, time?: number): Promise<any>;
    setColor(hexColor?: string, time?: number): Promise<any>;
    setAlpha(alpha: number, time?: number): Promise<any>;
    setVisible(visible: boolean, time?: number): Promise<any>;
    getMetadata(): Metadata.Element3DMetadata;
    destroy(): void;
    activateElement(self: ByondInteractiveElement): Promise<void>;
    deactivateElement(): Promise<void>;
    set isActive(active: boolean);
    get isActive(): boolean;
    handleDependencies(): Promise<void>;
    showRotationHandles(show: boolean): void;
    showScaleHandles(show: boolean): void;
    getMinVector(): Vector3;
    getMaxVector(): Vector3;
    HandleElementEventsAttribute(): void;
    triggerOnEvent(onEvent: OnEvent[]): Promise<void>;
    triggerFlow(flow: Flow): Promise<void>;
    triggerStep(step: Step): Promise<void>;
    triggerTouchElement(step: Step): Promise<void>;
    triggerAsyncStep(step: Step): Promise<void>;
}
