import { Color, Object3D, Vector3, Quaternion, MeshBasicMaterial, MeshLambertMaterial, Vector2, Euler, Texture, Material, MeshStandardMaterial, Box3 } from 'three';
import { AppManager } from '../ByondViewer';
import { ByondBaseElement } from '../Core/ByondBaseElement';
import { ChromakeyMaterial } from '../Core/Materials/ChromakeyMaterial';
import { Core } from '..';
export declare type EasingType = (k: number) => number;
export declare namespace Utils {
    function matchObjToBounds(containedElement: Core.ByondInteractiveElement.ByondInteractiveElement, bounds: Vector3, bestFit: boolean, forcePosition: boolean, addBoundsToHierarchy?: boolean): void;
    function randomColor(): Color;
    function isHLS(url: string): boolean;
    function isImage(url: string): boolean;
    function isGif(url: string): boolean;
    function isSVG(url: string): boolean;
    function isVideo(url: string): boolean;
    function getExtension(url: string): string;
    function GetGeometryRatioFromTexture(texture: Texture, scaleFactor?: number): Vector2;
    function GetGeometryRatio(width: number, height: number, scaleFactor?: number): Vector2;
    function DegToRadVector(vector: Vector3): Euler;
    function RadToDegVector(vector: Vector3 | Euler): Euler;
    function GetDefaultEulerVector(obj: Object3D): Euler;
    function setPosition(obj: Object3D, vector: Vector3, time?: number, onUpdate?: Array<Function>, easing?: EasingType): Promise<any>;
    function exportGLB(appManager: AppManager): Promise<void>;
    function saveString(text: any, filename: any): void;
    function exportOBJ(appManager: AppManager): Promise<void>;
    function setEnvMap(appManager: AppManager, envMapParams: {
        url: string;
        intensity: number;
        optimizerWidth?: number;
    }, obj?: Object3D, thisMaterial?: MeshStandardMaterial | MeshBasicMaterial | ChromakeyMaterial | MeshBasicMaterial[]): Promise<void>;
    function setRotation(obj: Object3D, vector: Euler, time?: number, onUpdate?: Array<Function>): Promise<any>;
    function setScale(obj: Object3D, vector: Vector3, time?: number, onUpdate?: Array<Function>): Promise<any>;
    function setColor(material: MeshBasicMaterial | MeshLambertMaterial, hexColor?: string, time?: number, onUpdate?: Array<Function>): Promise<any>;
    function setAlpha(material: Material, alpha: number, time?: number, onUpdate?: Array<Function>): Promise<any>;
    function setHtmlAlpha(div: HTMLElement, alpha: number, time?: number, onUpdate?: Array<Function>): Promise<any>;
    function string2HtmlElement(str: string): HTMLElement;
    function sleep(ms: number): Promise<void>;
    function hexToRgb(hex: string): {
        r: number;
        g: number;
        b: number;
    };
    function getLookAtVector(obj: Object3D, offset?: number): Vector3;
    function setQuaternion(obj: Object3D, to: Quaternion, time?: number, onUpdate?: Array<Function>): Promise<any>;
    function getItemById(viewer: AppManager, byondId: string): ByondBaseElement;
    function byondPositionToThreePosition(position: any): any;
    function byondRotationToThreeRotation(rotation: any): any;
    function byondScaleToThreeScale(scale: any): any;
    function threePositionToByondPosition(position: Vector3): Vector3;
    function threeRotationToByondRotation(rotation: Euler): Euler;
    function SetBoxFromObj(box: Box3, obj: Object3D): Box3;
    function ExpandBoxByObj(box: Box3, obj: Object3D): Box3;
}
